#!/bin/sh
#
# This file generates a local version of the HTML documentation for the sC++
# distributed libraries.
#
# Made by Jan Madsen
# Last modified the 17 January 1997
# Copyright: Computer Network Laboratory, Computer Science Department,
#            Swiss Federal Institute of Technology, Lausanne, Switzerland

INSTALL=`pwd`/installation

for param in $* ; do
   case ${param} in
   INSTALL=*)
	INSTALL=`echo $param | sed 's/INSTALL=//g'`
   esac
done

echo "<TITLE> sC++ Library Documentation </TITLE>" > Libraries.html
echo "<H1> Documentation for the libraries provided with the sC++ distribution </H1>" >> Libraries.html
echo " " >> Libraries.html
echo "This page describes the different classes provided by the libraries found in the sC++ distribution. Each section names the library followed by the classes defined in this library (in alphabetic order). By Clicking on the class name the interface file will be loaded." >> Libraries.html
echo " " >> Libraries.html
echo "<H2> Collection </H2>" >> Libraries.html
echo "For the moment no documentation beside the header files are available for this library. Please consult the <a href="http://ltiwww.epfl.ch/sCxx">sC++ home page</a> to see if the documentation has become available." >> Libraries.html
echo "<p>" >> Libraries.html
echo "The library interface consist of the following header files:" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/chaine.h">chaine.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/collecBase.h">collecBase.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/collecId.h">collecId.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/collecTemp.h">collecTemp.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/collection.h">collection.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/collectionTri.h">collectionTri.h</a>" >> Libraries.html
#echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/noeud.h">noeud.h</a>" >> Libraries.html
#echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/objet.h">objet.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/objetVirtuel.h">objetVirtuel.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/sys.h">sys.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<H2> CppUtils </H2>" >> Libraries.html
echo " " >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/CharString.h">CharString</a>: Abstraction of the type 'char *'. It dynamically allocates and deallocates memory for the string hold in the object, as well as assuring that the string is always NULL terminated." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/DynamicArrayTemplate.h">DynamicArrayTemplate</a>: Template class to manage an unlimited list. The implementation is using an array meaning that accessing indexed elements can be done very fast." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/DynamicListTemplate.h">DynamicListTemplate</a>: Template class to manage an unlimited list. The implementation is using pointers so it only uses the necessairy memory for managing the list." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/Fifo.h">Fifo</a>: Implementation of a fifo queue. The elements has to derive publicly from the class FifoItem." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/FifoTemplate.h">FifoTemplate</a>: Template class which implements a fifo queue. The template parameter specifies the element type." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/GetOpts.h">GetOpts</a>: Class to parse and "decompose" command options passed to a program." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/ListTemplate.h">ListTemplate</a>: Template class implementing a dynamic list similar to DynamicTemplateList. It is preferred to use DynamicListTemplate instead of this class." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/Parser.h">Parser</a>: class that can parse a string returning each time the next token in the string. The separator characters can be chosen dynamically." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/RandomIntGenerator.h">RandomIntGenerator</a>: Class to generate Random numbers in a given range." >> Libraries.html
echo "<p>" >> Libraries.html
echo " " >> Libraries.html
echo "<H2> Graphical User Interface (GUI) </H2>" >> Libraries.html

# Image of the library (directory where to find the image).
GUI_OVERVIEW_IMAGE_DIR=`pwd`

echo " " >> Libraries.html
echo "The GUI library encapsultes a large part of Motif's and X's functionnalities into active objects. This allows you to wait on the acceptation of the function members instead of having to implement different callback functions for each Motif or X event. Each of the classes in the library makes an attempt to encapsulate a concept from Motif or X which then can be manipulated as an entity. The GUI class is somewhat special in that it is always necessairy to create such an object before any of the other object from this library. The GUI class contains some global information to communicate with the window system. The top-level containers (MainWindow, RowColumn, BulletinBoard, Form, PanedWindow, DrawingArea, ScrolledWindow, and XTerm) will automatically open a new window on the screen and therefore needs the GUI object when constructed. All the different classes (except for GUI) can be encapsulated (term used 'sub-objects') into each other as shown on the follwoing figure. For example a Form may be used as a global object (with the GUI object as container), or may be contained in a MainWindow, a RowColumn, a BulletinBoard, another Form object, a PanedWindow, a DrawingArea or a ScrolledWindow object." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<img src="${GUI_OVERVIEW_IMAGE_DIR}/gui.gif">" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/ArrowButton.h">ArrowButton</a>: The class creates and manages a clickable button. This button will display an arrow image which points in the specified direction." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/BasicPushButton.h">BasicPushButton</a>: Base class for types of buttons implemented in the library. This class provides some basic button management facilities." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/BulletinBoard.h">BulletinBoard</a>: This is a container object. It can contain other GUI library objects that will be displayed inside this container. Each object inside the BulletinBoard is placed on a specific coordinate and thus may not be easily resizeable. We recommend that you use either the Form or RowColumn classes instead." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/CheckBox.h">CheckBox</a>: This is a container class for ToggleButtons. The ToggleButtons contained in this object can be selected independantly of each other and several can be selected at the same time. If you need ToggleButtons that are mutually exclusive then see/use the class RadioBox." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/Command.h">Command</a>: This object contains two parts: a field for entering commands (or strings) and a list of commands previously entered. The user can either enter a new command or select one (by double clicking on a previous command). The entered/selected command string will then be returned to you (when calling 'CommandEntered')." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/DrawingArea.h">DrawingArea</a>: This class reserves space to draw in. You can use anything to draw inside it; in particuliar the library 'Graphe' can be used." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/Form.h">Form</a>: This container class implements a more sophisticated placement policy of sub-objects. In particuliar it is possible to attach a sub-object to the edges of this container, to attach two sub-objects together or even to specify a relative position of a sub-object within the Form object. When the sub-objects are attached to the window edges they will automatically be resized when the window is resized." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/GUI.h">GUI</a>: This object initializes the GUI window system (Motif and X). Usually you only need one instance of this class for which all the other windows (top-level containers) will use. You may create more than one instance if you need Motif or X connections with different resource sets. Motif and X resources can be passed to this object if necessairy." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/GUIMouse.h">GUIMouse</a>: This object allows you to get informed when you click on a button on the mouse or the mouse has moved. There is one set of methods for each mouse button (supposing the mouse has 3 buttons). A GUIMouse object is always associated with a DrawingArea." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/GUIRealizer.h">GUIRealizer</a>: This object allows you to to automatically open/display a window without having to explicitly call the Realize member on the top-level object. This is particularily usefull if you declare the GUI objects as global, non-pointer objects." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/GUITypes.h">GUITypes</a>: This file contains the special GUI types used in the other classes. It also contains some constant declarations to facilitate the passing of parameters to other objects in GUI." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/GWidget.h">GWidget</a>: The base class for most other GUI classes. This class implements some basic manipulation operations for all the other GUI objects. These are mainly resource modifying functions." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/GWindow.h">GWindow</a>: This is the base class for the different container objects found in GUI. A container object controls the size and location of it's sub-objects. It is however not necessairy to specify the size of the object as it will automatically adapt its size to the size of its sub-objects." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/Label.h">Label</a>: This object allows you to display a string. The string may contain a multi-line text but the whole text has to be in the same font. To use multiple fonts declare multiple Label objects." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/LabelPixmap.h">LabelPixmap</a>: This object displays graphical information in the englobing container. The displayed information cannot be manipulated by the user. The shown image has to be in the X11 pixmap format." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/List.h">List</a>: This class implements the basic list functionnalities needed by the GUI classes that manipulates list of strings." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/MainWindow.h">MainWindow</a>: This class implements an GUI abstraction of the Motif concept of MainWindow." >> Libraries.html
echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/Menu.h">Menu</a>: Base class for the different menu classes." >> Libraries.html
#echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/MenuBar.h">MenuBar</a>: This object encapsulates the entire menu bar. It will group the PullDownMenu objects added to it into a single menu bar that is displayed to the user. Each PullDownMenu is however responsible for treating it's own items. It will automatically open the PullDownMenu's when the user clicks on them." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/MenuButton.h">MenuButton</a>: This class implements a single menu item that the user may select from a menu (either in a PullDownMenu, OptionMenu or in a PopUpMenu). The manipulations on this object is mostly to specify if the object should be selectable or not." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/MultipleSelectionList.h">MultipleSelectionList</a>: This provides you with the ability to display a list of strings and let the user select one or more of them. If you only want the user to restrict the selection to one string at a time then use SingleSelectionList. " >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/OptionMenu.h">OptionMenu</a>:An OptionMenu is typically used to promt the user to choose a value. It displays a Label and a menu button that shows the current value. When the user clicks on the button, a menu that contains the rest of the choices is popped up directly on top of the button. Choosing an item from the menu modifies the menu button title so that it shows the currently-selected item." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/PanedWindow.h">PanedWindow</a>: This container object allows the user to resize the area occupied by each of the sub-objects inside the space allocated for the PanedWindow." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/PopUpMenu.h">PopUpMenu</a>: This object allows you to associate a popup menu with the third mouse button (i.e. when you click on the third mouse button the menu in this object will appear on the screen)." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/PullDownMenu.h">PullDownMenu</a>: Menu which has a fixed location inside a menu bar. When the user clicks on the name of the menu then it will display the different menu items and allow the user to chose one. By using the function 'ItemSelected' you can get the number of the menu item that was selected. A PullDownMenu may also contain other PullDownMenu's which then will be displayed as sub-menu's to the containing menu." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/PushButton.h">PushButton</a>: This class allows you to create a pushbutton with a text written in it. When the user clicks on it, it will automatically provide the graphical feedback and inform you via the acceptation of the call to Pressed." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/PushButtonPixmap.h">PushButtonPixmap</a>: This class allows you to create a button which display graphical information (normally an image, in the X11 pixmap format)." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/RadioBox.h">RadioBox</a>: This is a container class for ToggleButtons. When a ToggleButton contained in this object is selected then the ToggleButton previously selected is de-selected. If you need ToggleButtons that are not mutually exclusive then see/use the class CheckBox." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/RowColumn.h">RowColumn</a>: Container class, the sub-objects you put into it will automatically either be shown horizontally or vertically one beside/after another. The layout (attachments) are automatically done." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/Scale.h">Scale</a>: An object of this class allows the user to select a value in a given range of values. He selects it by using a slider (graphical entity similar to a scrollbar)." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/ScrolledWindow.h">ScrolledWindow</a>: This object contains another object which contains a (usually larger) output area. ScrolledWindow then allows the user to scroll around in the larger sub-object output area." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/Separator.h">Separator</a>: This class is used to separate different objects in a Container. The separator is displayed as a line between two GUI objects. Its only functionality is to provide a visual aid for the user of the interface." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/SimpleButtonContainer.h">SimpleButtonContainer</a>: Base class for the classes CheckBox, OptionMenu, PopUpmenu, PullDownMenu, RadioBox. The only method you need to use from this class is 'ItemSelected', which informs you which item is selected." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/SingleSelectionList.h">SingleSelectionList</a>: This provides you with the ability to display a list of strings and let the user select one of them. When the user select one any other line which was previously selected is deselected. If you will give the user the option to select more than one string at the same time the use MultipleSelectionList." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/Text.h">Text.h</a>:  This class provides text editing capabilities. Text objects can be used anywhere the user may type a free-form text. The text can be shown in two modes either with the ability of the user to modify the text or not." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/TextField.h">TextField</a>: This class provides the ability for the user to enter a single line of text." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/ToggleButton.h">ToggleButton</a>: The ToggleButton has a graphical indicator (a diamond) that indicates if the ToggleButton is on or off. A ToggleButton is always contained in one of the container classes CheckBox, PopUpMenu, PullDownMenu, RadioBox." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/XTerm.h">XTerm</a>: This object can be used to easily open a window that will react like a xterm window. " >> Libraries.html
echo "<p>" >> Libraries.html
echo "<H2> Geometrie2d </H2>" >> Libraries.html
echo "For the moment no documentation beside the header files are available for this library. Please consult the <a href="http://ltiwww.epfl.ch/sCxx">sC++ home page</a> to see if the documentation has become available." >> Libraries.html
echo "<p>" >> Libraries.html
echo "The library interface consist of the following header files:" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/arc.h">arc.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/calcul.h">calcul.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/cercle.h">cercle.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/droite.h">droite.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/geometrie.h">geometrie.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/segmentgeo.h">segmentgeo.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<H2> Graphe </H2>" >> Libraries.html
echo "For the moment no documentation beside the header files are available for this library. Please consult the <a href="http://ltiwww.epfl.ch/sCxx">sC++ home page </a> to see if the documentation has become available." >> Libraries.html
echo "<p>" >> Libraries.html
echo "The library interface consist of the following header files:" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/arc2d.h">arc2d.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/attrcouleur.h">attrcouleur.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/attrcurseur.h">attrcurseur.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/attrfonte.h">attrfonte.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/attrligne.h">attrligne.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/attrmarker.h">attrmarker.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/attrpix.h">attrpix.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/attrsolide.h">attrsolide.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/attrtexte.h">attrtexte.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/attrvisible.h">attrvisible.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/axe2d.h">axe2d.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/bloc.h">bloc.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/caractere.h">caractere.h</a>" >> Libraries.html
#echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/cercle2d.h">cercle2d.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/cloture.h">cloture.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/couleur.h">couleur.h</a>" >> Libraries.html
#echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/curseur.h">curseur.h</a>" >> Libraries.html
#echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/droite2d.h">droite2d.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/entite.h">entite.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/eventreport.h">eventreport.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/fenetre.h">fenetre.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/fonte.h">fonte.h</a>" >> Libraries.html
#echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/fontevar.h">fontevar.h</a>" >> Libraries.html
#echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/graphe.h">graphe.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/graphique.h">graphique.h</a>" >> Libraries.html
#echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/groupe.h">groupe.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/hachuretype.h">hachuretype.h</a>" >> Libraries.html
#echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/horizontalrub.h">horizontalrub.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/image.h">image.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/limite.h">limite.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/linearrub.h">linearrub.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/linetype.h">linetype.h</a>" >> Libraries.html
#echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/linewidth.h">linewidth.h</a>" >> Libraries.html
#echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/marker.h">marker.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/markertype.h">markertype.h</a>" >> Libraries.html
#echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/ncontrol.h">ncontrol.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/nfrein.h">nfrein.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/nindif.h">nindif.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/ninput.h">ninput.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/nmecanique.h">nmecanique.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/noeudtrans.h">noeudtrans.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/norient.h">norient.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/noutput.h">noutput.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/patterntype.h">patterntype.h</a>" >> Libraries.html
#echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/pixdef.h">pixdef.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/polyedre.h">polyedre.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/polygone.h">polygone.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/polyline.h">polyline.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/rectangle2d.h">rectangle2d.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/rectangletexte.h">rectangletexte.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/rectangularrub.h">rectangularrub.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/reference.h">reference.h</a>" >> Libraries.html
#echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/retour.h">retour.h</a>" >> Libraries.html
#echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/rubberband.h">rubberband.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
#echo "<a href="file://localhost${INSTALL}/include/segcar.h">segcar.h</a>" >> Libraries.html
#echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/segment.h">segment.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/spline.h">spline.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/texte.h">texte.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/varitexte.h">varitexte.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/verticalrub.h">verticalrub.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/vue.h">vue.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/xtogtype.h">xtogtype.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<H2> Matrice </H2>" >> Libraries.html
echo "For the moment no documentation beside the header files are available for this library. Please consult the <a href="http://ltiwww.epfl.ch/sCxx">sC++ home page </a> to see if the documentation has become available." >> Libraries.html
echo "<p>" >> Libraries.html
echo "The library interface consist of the following header files:" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/matrice.h">matrice.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/point.h">point.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/vecteur.h">vecteur.h</a>" >> Libraries.html
echo "<p>" >> Libraries.html
echo "<H2> Signal </H2>" >> Libraries.html
echo " " >> Libraries.html
echo "When using this library you have to specify an extra option on the command line. This option ('-DGNUCOR') has to appear before the name of file to be compiled. When linking your application you need to link with the kernel library named 'sc_s' instead of the normal kernel 'sc'." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/Signal.h">Signal</a>: This is an active object abstraction of the UNIX signal concept. The library ensures that we do not lose any signal. The names of the function members are largerly inspired by the UNIX function names." >> Libraries.html
echo " " >> Libraries.html
echo "<H2> Sockets </H2>" >> Libraries.html
echo " " >> Libraries.html
echo "To use this library you have to link with the standard C++ library libg++.a. This library does not come with the distribution but can be found at any GNU ftp site. To install it follow the instructions that comes with the libg++.a distribution." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/TCPSocket.h">TCPSocket, TCPSocketDaemon</a>: Classes that makes an abstraction of the Unix TCP sockets. The TCPSocket class is for the client side of the socket and TCPSocketDaemon to create a TCP socket daemon. The methods have the same names as the Unix functions (except they start with an uppercase letter)." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/UDPConn.h">UDPConn</a>: Class that makes an abstraction of the Unix UDP connection oriented sockets. The UDPSocket class is for the client side of the socket and UDPSocketDaemon to create a UDP socket daemon. The methods have the same names as the Unix functions (except they start with an uppercase letter)." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/UDPSocket.h">UDPSocket</a>: Class that makes an abstraction of the Unix UDP sockets. The methods have the same names as the Unix functions (except they start with an uppercase letter)." >> Libraries.html
echo "<p>" >> Libraries.html
echo "<a href="file://localhost${INSTALL}/include/UnixSocket.h">UnixSocket</a>: Active class abstraction of the Unix socket primitives. The methods have the same names as the Unix functions (except they start with an uppercase letter)." >> Libraries.html
echo " " >> Libraries.html
echo "<hr>" >> Libraries.html
echo "Last Updated the 24 January 1997 <p>" >> Libraries.html
echo "Jan Madsen (Jan.Madsen@di.epfl.ch)" >> Libraries.html

