/***********************************************************************
*   $Id$
*   descr:      template class fifo
*   author:     DIVIN Abel
*
*   $Log$
*
************************************************************************/

#ifndef _FIFOTEMPLATE_INC
#define _FIFOTEMPLATE_INC

template <class UserItem> class FifoTemplate {

  struct Item {
    Item *next;
    void *infoPtr;
    Item(void *item) { infoPtr = item; next = NULL; }
  };

  Item *first;
  Item *last;

public:
  FifoTemplate() { first = last = NULL; }

  ~FifoTemplate() {
    while (first != NULL) {
      Item *temp = first->next;
      delete (UserItem *) first->infoPtr; // free user data
      delete first;
      first = temp;
    }
  }

  // put an Item in FifoTemplate
  void Put(UserItem *m) {
    Item *item = new Item((void *)m);

    if (first == NULL)
	first = item;
    else
	last->next = item;
    
    last = item; 
  }

  // extract and return the reference to the first Item from FifoTemplate
  // NULL if no Item in FifoTemplate
  UserItem *Get() {
    Item *firstItem = first;
    UserItem *userData;

    if ( first != NULL ) {
      first = first->next;
      if (first == NULL) last = NULL;
      userData = (UserItem *)firstItem->infoPtr;
      delete firstItem;
      return ( userData );
    }
    else return NULL;
  }

  // return the reference to the first Item from FifoTemplate without extracting it
  // NULL if no Item in FifoTemplate
  UserItem *ReadFirst() {
    if (first != NULL)
	return (UserItem *)first->infoPtr;
    else
	return NULL;
  }

  // return 1 if FifoTemplate is empty, 0 otherwise
  int Empty() {return ( first == NULL );}
};
  
#endif
