// -*- mode: c++ ; outline-regexp:"[ 	/]*--------------------" -*-
// $Id: GetOpts.h,v 1.1 1995/01/20 13:53:37 furrer Exp $
// 
// Contens:	GetOpts.h
//
//		provide basic functionnalities to parse argument line
//		
//
// Author :	Marc Furrer
//              EPFL DI-LTI     furrer@di.epfl.ch
//              1015 Ecublens   + 41 21 693 2907
//              Switzerland     + 41 21 693 6600 (Fax)
//
// Creation : Fri Jan 20 1995
//
// $Author: furrer $
// $Date: 1995/01/20 13:53:37 $
// $Revision: 1.1 $
// $State: Exp $
// $Header: /users/demo/scpp/CppUtils/src/RCS/GetOpts.h,v 1.1 1995/01/20 13:53:37 furrer Exp $
// $Locker:  $
// $Log: GetOpts.h,v $
// Revision 1.1  1995/01/20  13:53:37  furrer
// Initial revision
//

/*
   How does it work ?

   First create a list of all the options available on the command line

   ex:  -verbose -debug -port, etc..

   then incoporate them in an array of GetOptsListItem
   each item is made up :
         first  field == exact name of the option
         second field == 1 if it is folowed by an argument, 0 otherwise
         third  field == internal use, put a 0
         fourth field == internal use, put a NULL
   the last item in the array shall by NULL, 0, 0, NULL

   ex:
         OptArgListItem mylist[] =
         {
              {"-drop",    1, 0, NULL},
              {"-delay",   1, 0, NULL},
              {"-verbose", 0, 0, NULL},
              {"-debug",   0, 0, NULL},
              {NULL,       0, 0, NULL}
         };

   then create an instance of GetOpts

   GetOpts getopts (mylist);

   analyse the argument line

   last = getopts (argc, argv)

   last will contain the index of the last item used in argv
   or -1 if an error occured.

   ex: if you analyse the folowing line with the options list above
           a.out -verbose -drop 1 decus.com 9944
       last will be 3

   to know if an options was given use

   int ok;
   ok = getopts.CheckOpt ("-verbose")

   ok will be 1 on success 0 otherwise

   if the options need an argument

   int ok;
   char* arg;

   ok = getopts.CheckOpt ("-drop", arg)

   ok will be 1 on success, 0 otherwise
   and arg will point the argument of the option (NULL if none)

*/

   
   
#ifndef _GETOPTS_H
#define _GETOPTS_H

typedef struct
{
    char* optname;
    int   optparam;
    char* optarg;
    int   present;
} GetOptsListItem;


class GetOpts
{
  private:
    GetOptsListItem* list;

  public:

    GetOpts (GetOptsListItem olist[])
      // will analys args list latter
      // olist, should not be changed in the mean time.
    {
        list = olist;
    }

    int Analyse(int argc, char* argv[]);
     // udpdate values in olist acording to argc and argv
     // return index in argv of the last argument
     // or -1 on failure

    int CheckOpt (char* optname);
    //check if option is present
    // return 1 on success, 0 otherwise

    int CheckOpt (char* optname, char*& optarg);
    //check if option is present
    // return 1 on success, 0 otherwise
    // set optarg to the argument read (NULL if not present)
};    

#endif
