/***********************************************************************
*   $Id$
*   descr:      template class ListTemplate
*               to manage static list of copy of user items
*
*               A current item position in list is managed.
*               Only adding and reading operations are defined
*
*   author:     DIVIN Abel
*
*   $Log$
*
************************************************************************/

#ifndef _LIST_TEMPLATE_INC
#define _LIST_TEMPLATE_INC

//#include <iostream.h>
//#include <strstream.h>
//#include <stdio.h>

template <class UserItem> class ListTemplate {
public:
  // ------------------------------------------------------------
  // contructor, create an empty list

  ListTemplate();

  // ------------------------------------------------------------
  // will destroy the list

  ~ListTemplate();

  // ------------------------------------------------------------
  // Add an Item at the end of the List

  virtual void Append(const UserItem &data);

  // ------------------------------------------------------------
  // Add an Item at the beginning of the List

  virtual void Prepend(const UserItem &data);

  // ------------------------------------------------------------
  // return next item from List without extracting it
  // and automatically move to next item in list
  // Exception is fired in case of :
  //   access to an empty list
  //   end of list already reached

  virtual UserItem ReadNext();


  // ------------------------------------------------------------
  // return 1 if end of list is reached
  //        0 if end of list is not reached

  virtual int EndOfList();


  // ------------------------------------------------------------
  // set current position in list to beginning of list

  virtual void Reset();


  // ------------------------------------------------------------
  // return 1 if List is empty, 0 otherwise

  virtual int IsEmpty() const;


  // ------------------------------------------------------------
  // return number of items in list

  virtual int Size() const;


  // ------------------------------------------------------------
  // empty the list
  // WARNING: user data will NOT be deleted

  virtual void Clear();

protected:
  struct Item {
    Item *next;                 // pointer to next item in list
    Item *previous;             // pointer to previous item in list
    UserItem userData;          // copy of user data
    
    // init item with user data
    Item(const UserItem &data): userData(data) { next = previous = NULL; }
  };

  int NrOfItems; // current number of items in List
  Item *first;   // pointer to first item in List
  Item *current; // pointer to current item in List used by ReadNextItem()
  Item *last;    // pointer to last item in List

  virtual void EmptyTheList();

  virtual void ThrowException(char *calledMethod, char *errMsg);
};

template<class UserItem> 
inline int ListTemplate<UserItem>::EndOfList() {
  return (current == NULL);
}

template<class UserItem> 
inline void ListTemplate<UserItem>::Reset() {
  current = first;
}

template<class UserItem> 
inline int ListTemplate<UserItem>::IsEmpty() const {
  return ( first == NULL );
}

template<class UserItem> 
inline int ListTemplate<UserItem>::Size() const {
  return ( NrOfItems );
}

template<class UserItem> 
inline void ListTemplate<UserItem>::EmptyTheList() {
  while (first != NULL) {
    Item *temp = first->next;  // save pointer to next before deleting first
    delete first;
    first = temp;
  }
  
  last = current = NULL;
  NrOfItems = 0;
}

template<class UserItem>
inline ListTemplate<UserItem>::ListTemplate() {
  NrOfItems = 0;
  first = last = current = NULL;
}

template<class UserItem>
inline ListTemplate<UserItem>::~ListTemplate() {
  EmptyTheList();
}

template<class UserItem>
inline void ListTemplate<UserItem>::Append(const UserItem &data) {
  Item *item;
  
  item = new Item(data);
  NrOfItems++;
  
  // if (empty List)
  if (first == NULL) {
    first = last = item;
  }
  // non empty list
  else {
    last->next = item;
    item->previous = last;
    last = item;
  }
}

template<class UserItem>
inline void ListTemplate<UserItem>::Prepend(const UserItem &data) {
  Item *item;
  
  item = new Item(data);
  NrOfItems++;

  if (first == NULL) {
    first = last = item;
  }
  else {
    item->next = first;
    first->previous = item;
    first = item;
  }
}

template<class UserItem>
inline UserItem ListTemplate<UserItem>::ReadNext () {

  // empty List
  if (first == NULL) {
    ThrowException("ListTemplate.ReadNext", "CANNOT perform action on empty list");
  }
  // end of list reached
  else if (current == NULL) {
    ThrowException("ListTemplate.ReadNext", "CANNOT perform action because end of list reached");
  }
  // current has a valid position
  else {
    Item *item = current;
    current = current->next;
    return item->userData;
  }
}

template<class UserItem>
inline void ListTemplate<UserItem>::Clear() {
  EmptyTheList();
  ListTemplate();
}

template<class UserItem>
inline void ListTemplate<UserItem>::ThrowException(char *calledMethod, 
						   char *errMsg) {
/*
  ostrstream ostream;

  ostream << "\n#ERR:" << calledMethod << ":" << errMsg << "\n";

#ifdef _EXCEPTIONS
    throw ostream.str;
#else
    cout << ostream.str();
    exit(1);
#endif
*/
}

#endif
