/*
 * Module UnixSocket : SC++ UNIX sockets and UNIX gate class definitions
 * Copyright: EPFL - LABORATOIRE DE TELEINFORMATIQUE
 * Author: Divin Abel
 */

#ifndef _SCPP_UnixSocket_INC
#define _SCPP_UnixSocket_INC

#include "UnixGate.h"

extern "C"{
#include  <netdb.h>
}
#include  <netinet/in.h>

// ---------------------------------
//  Definition of class UnixSocket
// ---------------------------------

active class UnixSocket {

  void Initialize();

  @UnixSocket();

public:
  UnixSocket(int &result, int family, int type, int protocol=0, int debug=0);
  UnixSocket(int UnixSocketDescriptor, int debug=0);

  ~UnixSocket();

  int descr;

  static void InitIOUnixSockets();
  static void KillIOUnixSockets();

  // synchronous methods, same interface as UNIX functions
  int Connect(struct sockaddr *name, int namelen); // return 0: success, -1: failure
  int Bind(struct sockaddr *name, int namelen);
  int Listen(int backlog=5);
  int Close();
  int GetDescr();

 // return socket object, NULL if error
  UnixSocket *Accept(struct sockaddr *addr=NULL, int *addrlen=NULL);

  int Recv(char *buf, int len, int flags=0);
  int Send(char *msg, int len, int flags=0);
  int Read(char *buf, int nbyte);
  int Write(char *buf, int nbyte);
  int RecvFrom(char *buf, int len, int flags, struct sockaddr *fromSoc=NULL, int *fromlen=NULL);
  int SendTo(char *msg, int len, int flags, struct sockaddr *to, int tolen);
  int RecvMsg(struct msghdr *msg, int flags=0);
  int SendMsg(struct msghdr *msg, int flags=0);

};

active class UDPBase {

  void Initialize();

  @UDPBase();

protected:
  int descr;
  int udp_connected;

  struct sockaddr dest_addr;
  int dest_len;

  struct sockaddr address;
  int address_len;

public:

  UDPBase(int &retval, int debug=0);
  UDPBase(char *dummy, int s, int debug=0);

  ~UDPBase();

  // synchronous methods
  int Bind(struct sockaddr *address,int address_len);
  int Close();
  void Dummy(); // private use, will be accepted instead of Send/Recv after a disconnect
  void Disconnect();

  int Send(char* msg,int len, int flags=0);
  int Recv(char* buf,int len, int flags=0);
};

extern UnixSocket *s0,*s1;

#endif /* _SCPP_UnixSocket_INC */
